@@ -82,6 +82,12 @@ class Risk(NetBoxModel):
     )
     comments = models.TextField(blank=True)
 
+    tags = models.ForeignKey(
+        to=ContentType,
+        on_delete=models.CASCADE,
+        related_name='risk_tags'
+    )
+
     class Meta:
         ordering = ['name']
 
@@ -125,11 +131,6 @@ class RiskRelation(NetBoxModel):
         blank=True,
     )
 
-    models.CharField(
-        max_length=250,
-        unique=False,
-        related_name='risk_relation_tag'
-    )
 
     class Meta:
         ordering = ['name']
